@@ -1,3 +1,6 @@
+#![feature(trait_alias)]
+#![cfg_attr(not(target_arch = "wasm32"), allow(dead_code, unused_imports))]
+
 #[macro_use]
 extern crate num_derive;
 
@@ -41,3 +44,9 @@ pub use kdf::*;
 
 pub mod encryption;
 pub use encryption::*;
+
+pub mod ecdsa;
+pub use crate::ecdsa::*;
+
+pub mod bsm;
+pub use bsm::*;
